@@ -116,6 +116,7 @@ typedef struct {
     sentry_path_t *event_path;
     sentry_path_t *breadcrumb1_path;
     sentry_path_t *breadcrumb2_path;
+    sentry_path_t *external_report_path;
     size_t num_breadcrumbs;
     std::atomic<bool> crashed;
     std::atomic<bool> scope_flush;
@@ -188,7 +189,7 @@ crashpad_register_wer_module(
 #endif
 
 static void
-crashpad_backend_flush_scope_to_event(const sentry_path_t *event_path,
+flush_scope_to_event(const sentry_path_t *event_path,
     const sentry_options_t *options, sentry_value_t crash_event)
 {
     SENTRY_WITH_SCOPE (scope) {
@@ -212,6 +213,25 @@ crashpad_backend_flush_scope_to_event(const sentry_path_t *event_path,
     }
 }
 
+// Prepares an envelope with DSN, event ID, and session if available, for an
+// external crash reporter.
+static void
+flush_external_crash_report(
+    const sentry_options_t *options, const sentry_uuid_t *crash_event_id)
+{
+    sentry_envelope_t *envelope = sentry__envelope_new();
+    if (!envelope) {
+        return;
+    }
+    sentry__envelope_set_event_id(envelope, crash_event_id);
+    if (options->session) {
+        sentry__envelope_add_session(envelope, options->session);
+    }
+
+    sentry__run_write_external(options->run, envelope);
+    sentry_envelope_free(envelope);
+}
+
 // This function is necessary for macOS since it has no `FirstChanceHandler`.
 // but it is also necessary on Windows if the WER handler is enabled.
 // This means we have to continuously flush the scope on
@@ -244,7 +264,10 @@ crashpad_backend_flush_scope(
     sentry_value_set_by_key(
         event, "level", sentry__value_new_level(SENTRY_LEVEL_FATAL));
 
-    crashpad_backend_flush_scope_to_event(data->event_path, options, event);
+    flush_scope_to_event(data->event_path, options, event);
+    if (data->external_report_path) {
+        flush_external_crash_report(options, &data->crash_event_id);
+    }
     data->scope_flush.store(false, std::memory_order_release);
 #endif
 }
@@ -267,8 +290,10 @@ flush_scope_from_handler(
     }
 
     // now we are the sole flusher and can flush into the crash event
-    crashpad_backend_flush_scope_to_event(
-        state->event_path, options, crash_event);
+    flush_scope_to_event(state->event_path, options, crash_event);
+    if (state->external_report_path) {
+        flush_external_crash_report(options, &state->crash_event_id);
+    }
 }
 
 #    ifdef SENTRY_PLATFORM_WINDOWS
@@ -474,6 +499,22 @@ crashpad_backend_startup(
         sentry__path_free(screenshot_path);
     }
 
+    base::FilePath crash_reporter;
+    base::FilePath crash_envelope;
+    if (options->external_crash_reporter) {
+        char *filename
+            = sentry__uuid_as_filename(&data->crash_event_id, ".envelope");
+        data->external_report_path
+            = sentry__path_join_str(options->run->external_path, filename);
+        sentry_free(filename);
+
+        if (data->external_report_path) {
+            crash_reporter
+                = base::FilePath(options->external_crash_reporter->path);
+            crash_envelope = base::FilePath(data->external_report_path->path);
+        }
+    }
+
     std::vector<std::string> arguments { "--no-rate-limit" };
 
     // Initialize database first, flushing the consent later on as part of
@@ -501,7 +542,7 @@ crashpad_backend_startup(
         minidump_url ? minidump_url : "", proxy_url, annotations, arguments,
         /* restartable */ true,
         /* asynchronous_start */ false, attachments, screenshot,
-        options->crashpad_wait_for_upload);
+        options->crashpad_wait_for_upload, crash_reporter, crash_envelope);
     sentry_free(minidump_url);
 
 #ifdef SENTRY_PLATFORM_WINDOWS
@@ -614,6 +655,7 @@ crashpad_backend_free(sentry_backend_t *backend)
     sentry__path_free(data->event_path);
     sentry__path_free(data->breadcrumb1_path);
     sentry__path_free(data->breadcrumb2_path);
+    sentry__path_free(data->external_report_path);
     sentry_free(data);
 }
 
