@@ -11,6 +11,7 @@
 #include "sentry_logs.h"
 #include "sentry_options.h"
 #include "sentry_path.h"
+#include "sentry_process.h"
 #include "sentry_random.h"
 #include "sentry_scope.h"
 #include "sentry_session.h"
@@ -19,7 +20,9 @@
 #include "sentry_tracing.h"
 #include "sentry_transport.h"
 #include "sentry_tsan.h"
+#include "sentry_uuid.h"
 #include "sentry_value.h"
+#include "transports/sentry_disk_transport.h"
 
 #ifdef SENTRY_PLATFORM_WINDOWS
 #    include "sentry_os.h"
@@ -1493,6 +1496,48 @@ sentry_capture_feedback(sentry_value_t user_feedback)
     }
 }
 
+bool
+sentry__launch_external_crash_reporter(sentry_envelope_t *envelope)
+{
+    SENTRY_WITH_OPTIONS (options) {
+        if (!options->external_crash_reporter) {
+            return false;
+        }
+
+        sentry_uuid_t event_id = sentry__envelope_get_event_id(envelope);
+        char *envelope_filename
+            = sentry__uuid_as_filename(&event_id, ".envelope");
+        if (!envelope_filename) {
+            return false;
+        }
+
+        sentry_path_t *report_path = sentry__path_join_str(
+            options->run->external_path, envelope_filename);
+        if (!report_path) {
+            sentry_free(envelope_filename);
+            return false;
+        }
+
+        // capture the envelope with the disk transport
+        sentry_transport_t *disk_transport
+            = sentry_new_external_disk_transport(options->run);
+        if (!disk_transport) {
+            sentry__path_free(report_path);
+            sentry_free(envelope_filename);
+            return false;
+        }
+        sentry__capture_envelope(disk_transport, envelope);
+        sentry__transport_dump_queue(disk_transport, options->run);
+        sentry_transport_free(disk_transport);
+
+        sentry__process_spawn(
+            options->external_crash_reporter, report_path->path, NULL);
+        sentry__path_free(report_path);
+        sentry_free(envelope_filename);
+    }
+    return true;
+}
+
 int
 sentry_get_crashed_last_run(void)
 {
