@@ -335,9 +335,13 @@ static
     case 'X':
     case 'o': {
         unsigned long long int val = va_arg(*args_copy, unsigned long long int);
+        // TODO update once unsigned 64-bit can be sent as non-string
+        char buf[26];
+        char format[8];
+        snprintf(format, sizeof(format), "%%ll%c", conversion);
+        snprintf(buf, sizeof(buf), format, val);
         sentry_value_set_by_key(
-            param_obj, "value", sentry_value_new_uint64(val));
-        // TODO update once unsigned 64-bit can be sent
+            param_obj, "value", sentry_value_new_string(buf));
         sentry_value_set_by_key(
             param_obj, "type", sentry_value_new_string("string"));
         break;
@@ -501,11 +505,17 @@ static
 /**
  * This function assumes that `value` is owned, so we have to make sure that the
  * `value` was created or cloned by the caller or even better inc_refed.
+ *
+ * Replaces attributes[name] if it already exists.
  */
 static void
 add_attribute(sentry_value_t attributes, sentry_value_t value, const char *type,
     const char *name)
 {
+    if (!sentry_value_is_null(sentry_value_get_by_key(attributes, name))) {
+        // already exists, so we remove and create a new one
+        sentry_value_remove_by_key(attributes, name);
+    }
     sentry_value_t param_obj = sentry_value_new_object();
     sentry_value_set_by_key(param_obj, "value", value);
     sentry_value_set_by_key(param_obj, "type", sentry_value_new_string(type));
@@ -598,6 +608,10 @@ add_scope_and_options_data(sentry_value_t log, sentry_value_t attributes)
         }
     }
 
+    // fallback in case options doesn't set it
+    add_attribute(attributes, sentry_value_new_string(SENTRY_SDK_NAME),
+        "string", "sentry.sdk.name");
+
     SENTRY_WITH_OPTIONS (options) {
         if (options->environment) {
             add_attribute(attributes,
@@ -608,10 +622,11 @@ add_scope_and_options_data(sentry_value_t log, sentry_value_t attributes)
             add_attribute(attributes, sentry_value_new_string(options->release),
                 "string", "sentry.release");
         }
+        add_attribute(attributes,
+            sentry_value_new_string(sentry_options_get_sdk_name(options)),
+            "string", "sentry.sdk.name");
     }
 
-    add_attribute(attributes, sentry_value_new_string("sentry.native"),
-        "string", "sentry.sdk.name");
     add_attribute(attributes, sentry_value_new_string(sentry_sdk_version()),
         "string", "sentry.sdk.version");
 }
