@@ -51,6 +51,7 @@ sentry_options_new(void)
     opts->attach_screenshot = false;
     opts->crashpad_wait_for_upload = false;
     opts->enable_logging_when_crashed = true;
+    opts->propagate_traceparent = false;
     opts->symbolize_stacktraces =
     // AIX doesn't have reliable debug IDs for server-side symbolication,
     // and the diversity of Android makes it infeasible to have access to debug
@@ -99,6 +100,7 @@ sentry_options_free(sentry_options_t *opts)
     sentry_free(opts->transport_thread_name);
     sentry__path_free(opts->database_path);
     sentry__path_free(opts->handler_path);
+    sentry__path_free(opts->external_crash_reporter);
     sentry_transport_free(opts->transport);
     sentry__backend_free(opts->backend);
     sentry__attachments_free(opts->attachments);
@@ -566,6 +568,22 @@ sentry_options_set_database_path_n(
     opts->database_path = sentry__path_from_str_n(path, path_len);
 }
 
+void
+sentry_options_set_external_crash_reporter_path(
+    sentry_options_t *opts, const char *path)
+{
+    sentry__path_free(opts->external_crash_reporter);
+    opts->external_crash_reporter = sentry__path_from_str(path);
+}
+
+void
+sentry_options_set_external_crash_reporter_path_n(
+    sentry_options_t *opts, const char *path, size_t path_len)
+{
+    sentry__path_free(opts->external_crash_reporter);
+    opts->external_crash_reporter = sentry__path_from_str_n(path, path_len);
+}
+
 #ifdef SENTRY_PLATFORM_WINDOWS
 void
 sentry_options_add_attachmentw_n(
@@ -612,6 +630,22 @@ sentry_options_set_handler_pathw(sentry_options_t *opts, const wchar_t *path)
     sentry_options_set_handler_pathw_n(opts, path, path_len);
 }
 
+void
+sentry_options_set_external_crash_reporter_pathw_n(
+    sentry_options_t *opts, const wchar_t *path, size_t path_len)
+{
+    sentry__path_free(opts->external_crash_reporter);
+    opts->external_crash_reporter = sentry__path_from_wstr_n(path, path_len);
+}
+
+void
+sentry_options_set_external_crash_reporter_pathw(
+    sentry_options_t *opts, const wchar_t *path)
+{
+    size_t path_len = path ? wcslen(path) : 0;
+    sentry_options_set_external_crash_reporter_pathw_n(opts, path, path_len);
+}
+
 void
 sentry_options_set_database_pathw_n(
     sentry_options_t *opts, const wchar_t *path, size_t path_len)
@@ -718,3 +752,16 @@ sentry_options_set_handler_strategy(
 }
 
 #endif // SENTRY_PLATFORM_LINUX
+
+void
+sentry_options_set_propagate_traceparent(
+    sentry_options_t *opts, int propagate_traceparent)
+{
+    opts->propagate_traceparent = !!propagate_traceparent;
+}
+
+int
+sentry_options_get_propagate_traceparent(const sentry_options_t *opts)
+{
+    return opts->propagate_traceparent;
+}
